.. _api:

*************
API Reference
*************

.. toctree::
    marshmallow.schema
    marshmallow.fields
    marshmallow.decorators
    marshmallow.validate
    marshmallow.utils
    marshmallow.error_store
    marshmallow.class_registry
    marshmallow.exceptions

.. automodule:: marshmallow
   :members:
   :undoc-members:
   :autosummary:

.. data:: EXCLUDE
.. data:: INCLUDE
.. data:: RAISE
.. data:: missing
